<?php

namespace App\Http\Controllers\Api;

use App\Models\Participant;
use App\Models\AutoDraw;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\ParticipantResource;
use App\Http\Resources\SeedResource;
use App\Http\Requests\StoreParticipantRequest;
use Illuminate\Support\Facades\Storage;
use App\Http\Requests\UpdateParticipantRequest;

class ParticipantController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response\Json\AnonymousResourceCollection
     */
    public function index()
    {
        return ParticipantResource::collection(Participant::query()->orderBy('id', 'asc')->get());
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreParticipantRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreParticipantRequest $request)
    {
        $data = $request->validated();
        $item = Participant::create($data);
        return response(new ParticipantResource($item), 201);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Participant  $item
     * @return \Illuminate\Http\Response
     */
    public function show(Participant $item)
    {
        return new ParticipantResource($item);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateParticipantRequest  $request
     * @param  \App\Models\Participant  $item
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateParticipantRequest $request, Participant $item)
    {
        $data = $request->validated();
        $item->update($data);
    }
    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Participant  $item
     * @return \Illuminate\Http\Response
     */
    public function destroy(Participant $item)
    {
        $item->delete();
        return response("", 204);
    }
}
